@@ -182,10 +182,12 @@ module ActionController #:nodoc:
     # responds to :to_format and display it.
     #
     def to_format
-      if get? || !has_errors? || response_overridden?
+      if !get? && has_errors? && !response_overridden?
+        display_errors
+      elsif has_view_rendering? || response_overridden?
         default_render
       else
-        display_errors
+        api_behavior
       end
     rescue ActionView::MissingTemplate
       api_behavior
@@ -198,7 +200,7 @@ module ActionController #:nodoc:
       if get?
         raise error
       elsif has_errors? && default_action
-        render :action => default_action
+        render rendering_options
       else
         redirect_to navigation_location
       end
@@ -273,6 +275,10 @@ module ActionController #:nodoc:
       Renderers::RENDERERS.include?(format)
     end
 
+    def has_view_rendering?
+      controller.class.include? ActionView::Rendering
+    end
+
     # By default, render the <code>:edit</code> action for HTML requests with errors, unless
     # the verb was POST.
     #
@@ -291,5 +297,13 @@ module ActionController #:nodoc:
     def response_overridden?
       @default_response.present?
     end
+
+    def rendering_options
+      if options[:render]
+        options[:render]
+      else
+        { action: default_action }
+      end
+    end
   end
 end
